# coding: utf-8

"""
    Montelo API SDK

    This server handles creating traces and logs.

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from montelo.client.api.datapoint_api import DatapointApi


class TestDatapointApi(unittest.TestCase):
    """DatapointApi unit test stubs"""

    def setUp(self) -> None:
        self.api = DatapointApi()

    def tearDown(self) -> None:
        pass

    def test_datapoint_controller_add_to_dataset_by_slug(self) -> None:
        """Test case for datapoint_controller_add_to_dataset_by_slug

        """
        pass

    def test_datapoint_controller_batch_add_to_dataset_by_slug(self) -> None:
        """Test case for datapoint_controller_batch_add_to_dataset_by_slug

        """
        pass


if __name__ == '__main__':
    unittest.main()
