# coding: utf-8

"""
    Montelo API SDK

    This server handles creating traces and logs.

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from montelo.client.models.full_dataset_dto import FullDatasetDto

class TestFullDatasetDto(unittest.TestCase):
    """FullDatasetDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FullDatasetDto:
        """Test FullDatasetDto
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FullDatasetDto`
        """
        model = FullDatasetDto()
        if include_optional:
            return FullDatasetDto(
                id = '',
                env_id = '',
                slug = '',
                name = '',
                description = '',
                input_schema = None,
                output_schema = None,
                is_fine_tuning = True,
                datapoints = [
                    montelo.client.models.datapoint_dto.DatapointDto(
                        id = '', 
                        input = montelo.client.models.input.input(), 
                        expected_output = montelo.client.models.expected_output.expectedOutput(), 
                        source = 'TRACE', 
                        source_id = '', 
                        dataset_id = '', 
                        split = 'TRAIN', 
                        created_at = '', 
                        metadata = montelo.client.models.metadata.metadata(), )
                    ]
            )
        else:
            return FullDatasetDto(
                id = '',
                env_id = '',
                slug = '',
                name = '',
                input_schema = None,
                output_schema = None,
                is_fine_tuning = True,
                datapoints = [
                    montelo.client.models.datapoint_dto.DatapointDto(
                        id = '', 
                        input = montelo.client.models.input.input(), 
                        expected_output = montelo.client.models.expected_output.expectedOutput(), 
                        source = 'TRACE', 
                        source_id = '', 
                        dataset_id = '', 
                        split = 'TRAIN', 
                        created_at = '', 
                        metadata = montelo.client.models.metadata.metadata(), )
                    ],
        )
        """

    def testFullDatasetDto(self):
        """Test FullDatasetDto"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
