# coding: utf-8

"""
    Montelo API SDK

    This server handles creating traces and logs.

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from montelo.client.models.create_dataset_input import CreateDatasetInput

class TestCreateDatasetInput(unittest.TestCase):
    """CreateDatasetInput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CreateDatasetInput:
        """Test CreateDatasetInput
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateDatasetInput`
        """
        model = CreateDatasetInput()
        if include_optional:
            return CreateDatasetInput(
                name = '',
                description = '',
                input_schema = None,
                output_schema = None,
                is_fine_tuning = True
            )
        else:
            return CreateDatasetInput(
                name = '',
        )
        """

    def testCreateDatasetInput(self):
        """Test CreateDatasetInput"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
