# coding: utf-8

"""
    Montelo API SDK

    This server handles creating traces and logs.

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from montelo.client.models.create_log_input import CreateLogInput

class TestCreateLogInput(unittest.TestCase):
    """CreateLogInput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CreateLogInput:
        """Test CreateLogInput
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateLogInput`
        """
        model = CreateLogInput()
        if include_optional:
            return CreateLogInput(
                datapoint_run_id = '',
                log = montelo.client.models.log_input.LogInput(
                    id = 'clsj9nupk000108jp9pxdcx5c', 
                    name = 'Agent X', 
                    source = 'MANUAL', 
                    model = 'gpt-4', 
                    input = What is your name?, 
                    output = I am an AI. I do not have a name., 
                    start_time = '2024-02-12T03:55:29.161Z', 
                    end_time = '2024-02-12T03:56:29.161Z', 
                    duration = 1.32, 
                    tokens = montelo.client.models.token_info.TokenInfo(
                        input_tokens = 5, 
                        output_tokens = 5, 
                        total_tokens = 10, ), 
                    extra = montelo.client.models.extra.extra(), ),
                trace = montelo.client.models.trace_input.TraceInput(
                    id = 'clsj9nupk000108jp9pxdcx5c', 
                    name = 'Top-level Trace', 
                    user_id = '', 
                    extra = montelo.client.models.extra.extra(), )
            )
        else:
            return CreateLogInput(
                log = montelo.client.models.log_input.LogInput(
                    id = 'clsj9nupk000108jp9pxdcx5c', 
                    name = 'Agent X', 
                    source = 'MANUAL', 
                    model = 'gpt-4', 
                    input = What is your name?, 
                    output = I am an AI. I do not have a name., 
                    start_time = '2024-02-12T03:55:29.161Z', 
                    end_time = '2024-02-12T03:56:29.161Z', 
                    duration = 1.32, 
                    tokens = montelo.client.models.token_info.TokenInfo(
                        input_tokens = 5, 
                        output_tokens = 5, 
                        total_tokens = 10, ), 
                    extra = montelo.client.models.extra.extra(), ),
        )
        """

    def testCreateLogInput(self):
        """Test CreateLogInput"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
