# coding: utf-8

"""
    Montelo API SDK

    This server handles creating traces and logs.

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from montelo.client.api.logs_api import LogsApi


class TestLogsApi(unittest.TestCase):
    """LogsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = LogsApi()

    def tearDown(self) -> None:
        pass

    def test_logs_controller_create_log(self) -> None:
        """Test case for logs_controller_create_log

        """
        pass

    def test_logs_controller_end_log(self) -> None:
        """Test case for logs_controller_end_log

        """
        pass


if __name__ == '__main__':
    unittest.main()
