# coding: utf-8

"""
    Montelo API SDK

    This server handles creating traces and logs.

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from montelo.client.models.datapoint_run_dto import DatapointRunDto

class TestDatapointRunDto(unittest.TestCase):
    """DatapointRunDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DatapointRunDto:
        """Test DatapointRunDto
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DatapointRunDto`
        """
        model = DatapointRunDto()
        if include_optional:
            return DatapointRunDto(
                id = '',
                experiment_id = '',
                datapoint_id = '',
                output = None
            )
        else:
            return DatapointRunDto(
                id = '',
                experiment_id = '',
                datapoint_id = '',
                output = None,
        )
        """

    def testDatapointRunDto(self):
        """Test DatapointRunDto"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
